#!/usr/bin/env python3

"""
NAME:
	add_secondary.py - create an entry in secondary.zones

SYNOPSIS:
	add_secondary.pl -Z "zones" "primaries" "zone" ...

DESCRIPTION:
	This script creates an entry in 'secondary.zones' for each "zone"
	with transfers comming from the nominated "primaries".  If more
	than one primary server "primaries" should be a coma separated
	list. 
	
	Options:

	-Z "zones"
		Tells us where to write the entries (secondary.zones).
	
AUTHOR:
	Simon J. Gerraty <sjg@crufty.net>

"""

"""
RCSid:
	$Id: add_secondary.py,v 1.3 2023/06/06 22:43:08 sjg Exp $

	@(#) Copyright (c) 1997-2023 Simon J. Gerraty.

	This file is provided in the hope that it will
	be of use.  There is absolutely NO WARRANTY.
	Permission to copy, redistribute or otherwise
	use this file is hereby granted provided that 
	the above copyright notice and this notice are
	left intact. 
      
	Please send copies of changes and bug-fixes to:
	sjg@crufty.net
"""

import sys
import dnsutils
import conf as cf

def add_secondary(args, conf):
    """Add zones for primaries"""

    primaries = '; '.join(args[0].split(','))
    szout = open(conf.get('secondary_zones','secondary.zones'), 'a')
    secondary_dir = conf.get('secondary_dir', 'secondary')
    for zone in args[1:]:
        if '.arpa' in zone:
            a = zone.split('.')
            a.reverse()
            zfile = '{}/{}'.format(secondary_dir, '.'.join(a[2:]).strip('.0'))
        else:
            zfile = '{}/{}'.format(secondary_dir, zone)
        print('\nzone "{}" {{\n\ttype secondary;\n\tprimaries {{ {}; }}\n\tfile "{}";\n}};\n'.format(zone, primaries, zfile), file=szout)
                
def myopts(o, a, conf):
    if o == '-Z':
        conf['secondary_zones'] = a

if __name__ == '__main__':

    conf = {
        'secondary_zones': 'secondary.zones',
        }
    conf,args = dnsutils.app_init('Z:', myopts, conf)

    add_secondary(args, conf)
    sys.exit(0)

